@@ -3,9 +3,9 @@
 //! This crate allows you to read and write PCD point cloud.
 
 #[doc(hidden)]
-pub extern crate anyhow;
+pub use anyhow;
 #[doc(hidden)]
-pub extern crate byteorder;
+pub use byteorder;
 
 pub mod error;
 pub mod metas;
@@ -17,6 +17,7 @@ pub mod writer;
 
 pub use error::Error;
 pub use metas::{DataKind, FieldDef, PcdMeta, Schema, TypeKind, ValueKind, ViewPoint};
+#[cfg(feature = "derive")]
 pub use pcd_rs_derive::{PcdDeserialize, PcdSerialize};
 pub use reader::{DynReader, Reader};
 pub use record::{DynRecord, Field, PcdDeserialize, PcdSerialize};
